@@ -8,7 +8,6 @@ import (
 	"errors"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"os"
 	"path/filepath"
 	"regexp"
@@ -21,6 +20,10 @@ import (
 	"github.com/go-git/go-git/v5/plumbing/format/gitignore"
 	"github.com/joho/godotenv"
 
+	"github.com/imdario/mergo"
+	"github.com/kballard/go-shellquote"
+	"github.com/spf13/pflag"
+
 	"github.com/docker/cli/cli/connhelper"
 	"github.com/docker/docker/api/types"
 	"github.com/docker/docker/api/types/container"
@@ -53,7 +56,7 @@ type NewContainerInput struct {
 	Privileged  bool
 	UsernsMode  string
 	Platform    string
-	Hostname    string
+	Options     string
 }
 
 // FileEntry is a file to copy to a container
@@ -370,6 +373,52 @@ func (cr *containerReference) remove() common.Executor {
 	}
 }
 
+func (cr *containerReference) mergeContainerConfigs(ctx context.Context, config *container.Config, hostConfig *container.HostConfig) (*container.Config, *container.HostConfig, error) {
+	logger := common.Logger(ctx)
+	input := cr.input
+
+	if input.Options == "" {
+		return config, hostConfig, nil
+	}
+
+	// parse configuration from CLI container.options
+	flags := pflag.NewFlagSet("container_flags", pflag.ContinueOnError)
+	copts := addFlags(flags)
+
+	optionsArgs, err := shellquote.Split(input.Options)
+	if err != nil {
+		return nil, nil, fmt.Errorf("Cannot split container options: '%s': '%w'", input.Options, err)
+	}
+
+	err = flags.Parse(optionsArgs)
+	if err != nil {
+		return nil, nil, fmt.Errorf("Cannot parse container options: '%s': '%w'", input.Options, err)
+	}
+
+	containerConfig, err := parse(flags, copts, "")
+	if err != nil {
+		return nil, nil, fmt.Errorf("Cannot process container options: '%s': '%w'", input.Options, err)
+	}
+
+	logger.Debugf("Custom container.Config from options ==> %+v", containerConfig.Config)
+
+	err = mergo.Merge(config, containerConfig.Config, mergo.WithOverride)
+	if err != nil {
+		return nil, nil, fmt.Errorf("Cannot merge container.Config options: '%s': '%w'", input.Options, err)
+	}
+	logger.Debugf("Merged container.Config ==> %+v", config)
+
+	logger.Debugf("Custom container.HostConfig from options ==> %+v", containerConfig.HostConfig)
+
+	err = mergo.Merge(hostConfig, containerConfig.HostConfig, mergo.WithOverride)
+	if err != nil {
+		return nil, nil, fmt.Errorf("Cannot merge container.HostConfig options: '%s': '%w'", input.Options, err)
+	}
+	logger.Debugf("Merged container.HostConfig ==> %+v", hostConfig)
+
+	return config, hostConfig, nil
+}
+
 func (cr *containerReference) create(capAdd []string, capDrop []string) common.Executor {
 	return func(ctx context.Context) error {
 		if cr.id != "" {
@@ -384,8 +433,8 @@ func (cr *containerReference) create(capAdd []string, capDrop []string) common.E
 			WorkingDir: input.WorkingDir,
 			Env:        input.Env,
 			Tty:        isTerminal,
-			Hostname:   input.Hostname,
 		}
+		logger.Debugf("Common container.Config ==> %+v", config)
 
 		if len(input.Cmd) != 0 {
 			config.Cmd = input.Cmd
@@ -417,7 +466,8 @@ func (cr *containerReference) create(capAdd []string, capDrop []string) common.E
 				OS:           desiredPlatform[0],
 			}
 		}
-		resp, err := cr.cli.ContainerCreate(ctx, config, &container.HostConfig{
+
+		hostConfig := &container.HostConfig{
 			CapAdd:      capAdd,
 			CapDrop:     capDrop,
 			Binds:       input.Binds,
@@ -425,10 +475,19 @@ func (cr *containerReference) create(capAdd []string, capDrop []string) common.E
 			NetworkMode: container.NetworkMode(input.NetworkMode),
 			Privileged:  input.Privileged,
 			UsernsMode:  container.UsernsMode(input.UsernsMode),
-		}, nil, platSpecs, input.Name)
-		if err != nil {
-			return fmt.Errorf("failed to create container: %w", err)
 		}
+		logger.Debugf("Common container.HostConfig ==> %+v", hostConfig)
+
+		config, hostConfig, err := cr.mergeContainerConfigs(ctx, config, hostConfig)
+		if err != nil {
+			return err
+		}
+
+		resp, err := cr.cli.ContainerCreate(ctx, config, hostConfig, nil, platSpecs, input.Name)
+		if err != nil {
+			return fmt.Errorf("failed to create container: '%w'", err)
+		}
+
 		logger.Debugf("Created container name=%s id=%v from image %v (platform: %s)", input.Name, resp.ID, input.Image, input.Platform)
 		logger.Debugf("ENV ==> %v", input.Env)
 
@@ -445,7 +504,7 @@ func (cr *containerReference) extractEnv(srcPath string, env *map[string]string)
 		// SOME_VAR=data=moredata
 		// SOME_VAR=datamoredata
 		singleLineEnvPattern = regexp.MustCompile(`^([^=]*)\=(.*)$`)
-		multiLineEnvPattern = regexp.MustCompile(`^([^<]+)<<(\w+)$`)
+		multiLineEnvPattern = regexp.MustCompile(`^([^<]+)<<([\w-]+)$`)
 	}
 
 	localEnv := *env
@@ -709,7 +768,7 @@ func (cr *containerReference) waitForCommand(ctx context.Context, isTerminal boo
 func (cr *containerReference) copyDir(dstPath string, srcPath string, useGitIgnore bool) common.Executor {
 	return func(ctx context.Context) error {
 		logger := common.Logger(ctx)
-		tarFile, err := ioutil.TempFile("", "act")
+		tarFile, err := os.CreateTemp("", "act")
 		if err != nil {
 			return err
 		}
