@@ -10,11 +10,9 @@ import (
 	"runtime"
 	"strings"
 
-	"github.com/kballard/go-shellquote"
 	"github.com/mitchellh/go-homedir"
 	"github.com/opencontainers/selinux/go-selinux"
 	log "github.com/sirupsen/logrus"
-	"github.com/spf13/pflag"
 
 	"github.com/nektos/act/pkg/common"
 	"github.com/nektos/act/pkg/common/git"
@@ -27,25 +25,22 @@ const ActPath string = "/var/run/act"
 
 // RunContext contains info about current job
 type RunContext struct {
-	Name             string
-	Config           *Config
-	Matrix           map[string]interface{}
-	Run              *model.Run
-	EventJSON        string
-	Env              map[string]string
-	ExtraPath        []string
-	CurrentStep      string
-	StepResults      map[string]*model.StepResult
-	ExprEval         ExpressionEvaluator
-	JobContainer     container.Container
-	OutputMappings   map[MappableOutput]MappableOutput
-	JobName          string
-	ActionPath       string
-	ActionRef        string
-	ActionRepository string
-	Inputs           map[string]interface{}
-	Parent           *RunContext
-	Masks            []string
+	Name           string
+	Config         *Config
+	Matrix         map[string]interface{}
+	Run            *model.Run
+	EventJSON      string
+	Env            map[string]string
+	ExtraPath      []string
+	CurrentStep    string
+	StepResults    map[string]*model.StepResult
+	ExprEval       ExpressionEvaluator
+	JobContainer   container.Container
+	OutputMappings map[MappableOutput]MappableOutput
+	JobName        string
+	ActionPath     string
+	Parent         *RunContext
+	Masks          []string
 }
 
 func (rc *RunContext) AddMask(mask string) {
@@ -126,7 +121,6 @@ func (rc *RunContext) startJobContainer() common.Executor {
 	return func(ctx context.Context) error {
 		logger := common.Logger(ctx)
 		image := rc.platformImage(ctx)
-		hostname := rc.hostname(ctx)
 		rawLogger := logger.WithField("raw_output", true)
 		logWriter := common.NewLineWriter(rc.commandHandler(ctx), func(s string) bool {
 			if rc.Config.LogOutput {
@@ -171,7 +165,7 @@ func (rc *RunContext) startJobContainer() common.Executor {
 			Privileged:  rc.Config.Privileged,
 			UsernsMode:  rc.Config.UsernsMode,
 			Platform:    rc.Config.ContainerArchitecture,
-			Hostname:    hostname,
+			Options:     rc.options(ctx),
 		})
 
 		return common.NewPipelineExecutor(
@@ -314,27 +308,14 @@ func (rc *RunContext) platformImage(ctx context.Context) string {
 	return ""
 }
 
-func (rc *RunContext) hostname(ctx context.Context) string {
-	logger := common.Logger(ctx)
+func (rc *RunContext) options(ctx context.Context) string {
 	job := rc.Run.Job()
 	c := job.Container()
 	if c == nil {
 		return ""
 	}
 
-	optionsFlags := pflag.NewFlagSet("container_options", pflag.ContinueOnError)
-	hostname := optionsFlags.StringP("hostname", "h", "", "")
-	optionsArgs, err := shellquote.Split(c.Options)
-	if err != nil {
-		logger.Warnf("Cannot parse container options: %s", c.Options)
-		return ""
-	}
-	err = optionsFlags.Parse(optionsArgs)
-	if err != nil {
-		logger.Warnf("Cannot parse container options: %s", c.Options)
-		return ""
-	}
-	return *hostname
+	return c.Options
 }
 
 func (rc *RunContext) isEnabled(ctx context.Context) (bool, error) {
@@ -438,8 +419,6 @@ func (rc *RunContext) getGithubContext(ctx context.Context) *model.GithubContext
 		Action:           rc.CurrentStep,
 		Token:            rc.Config.Token,
 		ActionPath:       rc.ActionPath,
-		ActionRef:        rc.ActionRef,
-		ActionRepository: rc.ActionRepository,
 		RepositoryOwner:  rc.Config.Env["GITHUB_REPOSITORY_OWNER"],
 		RetentionDays:    rc.Config.Env["GITHUB_RETENTION_DAYS"],
 		RunnerPerflog:    rc.Config.Env["RUNNER_PERFLOG"],
@@ -557,8 +536,7 @@ func nestedMapLookup(m map[string]interface{}, ks ...string) (rval interface{})
 	}
 }
 
-func (rc *RunContext) withGithubEnv(ctx context.Context, env map[string]string) map[string]string {
-	github := rc.getGithubContext(ctx)
+func (rc *RunContext) withGithubEnv(ctx context.Context, github *model.GithubContext, env map[string]string) map[string]string {
 	env["CI"] = "true"
 	env["GITHUB_ENV"] = ActPath + "/workflow/envs.txt"
 	env["GITHUB_PATH"] = ActPath + "/workflow/paths.txt"
